==> geopytool-0.8.20.0.203.tar.gz: geopytool-0.8.20.0.203/geopytool/cns.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="zh" sourcelanguage="en">
<context>
    <name>MainWindow</name>
    <message>
        <location filename="__init__.py" line="140"/>
        <source>GeoPyTool</source>
        <translation>GeoPyTool</translation>
    </message>
    <message>
        <location filename="__init__.py" line="744"/>
        <source>You are using GeoPyTool </source>
        <translation>你正在使用的是 GeoPyTool</translation>
    </message>
    <message>
        <location filename="__init__.py" line="745"/>
        <source>released on </source>
        <translation>发布日期为 </translation>
    </message>
    <message>
        <location filename="__init__.py" line="605"/>
        <source>Data File</source>
        <translation>数据文件</translation>
    </message>
    <message>
        <location filename="__init__.py" line="606"/>
        <source>Geochemistry</source>
        <translation>地球化学</translation>
    </message>
    <message>
        <location filename="__init__.py" line="607"/>
        <source>Calculation</source>
        <translation>多维度分析</translation>
    </message>
    <message>
        <location filename="__init__.py" line="608"/>
        <source>Structure</source>
        <translation>构造地质学</translation>
    </message>
    <message>
        <location filename="__init__.py" line="609"/>
        <source>Sedimentary</source>
        <translation>沉积相关</translation>
    </message>
    <message>
        <location filename="__init__.py" line="610"/>
        <source>Additional</source>
        <translation>附加功能</translation>
    </message>
    <message>
        <location filename="__init__.py" line="611"/>
        <source>MachineLearn</source>
        <translation>机器学习</translation>
    </message>
    <message>
        <location filename="__init__.py" line="612"/>
        <source>Help</source>
        <translation>帮助</translation>
    </message>
    <message>
        <location filename="__init__.py" line="613"/>
        <source>Language</source>
        <translation></translation>
    </message>
    <message>
        <location filename="__init__.py" line="615"/>
        <source>Combine</source>
        <translation>合并数据表</translation>
    </message>
    <message>
        <location filename="__init__.py" line="616"/>
        <source>Combine_transverse</source>
        <translation>合并转置</translation>
    </message>
    <message>
        <location filename="__init__.py" line="618"/>
        <source>Flatten</source>
        <translation>二维数据拉平成一维</translation>
    </message>
    <message>
        <location filename="__init__.py" line="620"/>
        <source>Trans</source>
        <translation>数据变换</translation>
    </message>
    <message>
        <location filename="__init__.py" line="622"/>
        <source>ReFormat</source>
        <translation>重新格式化</translation>
    </message>
    <message>
        <location filename="__init__.py" line="624"/>
        <source>Open Data</source>
        <translation>导入数据</translation>
    </message>
    <message>
        <location filename="__init__.py" line="625"/>
        <source>Close Data</source>
        <translation>关闭文件</translation>
    </message>
    <message>
        <location filename="__init__.py" line="626"/>
        <source>Set Format</source>
        <translation>设置数据</translation>
    </message>
    <message>
        <location filename="__init__.py" line="627"/>
        <source>Fill Blank with 0</source>
        <translation>用零值填充空白</translation>
    </message>
    <message>
        <location filename="__init__.py" line="628"/>
        <source>Save Data</source>
        <translation>保存数据</translation>
    </message>
    <message>
        <location filename="__init__.py" line="629"/>
        <source>Quit App</source>
        <translation>退出程序</translation>
    </message>
    <message>
        <location filename="__init__.py" line="631"/>
        <source>Remove LOI</source>
        <translation>去除烧式量</translation>
    </message>
    <message>
        <location filename="__init__.py" line="632"/>
        <source>Auto</source>
        <translation>常规地化图解计算自动生成</translation>
    </message>
    <message>
        <location filename="__init__.py" line="633"/>
        <source>TAS</source>
        <translation>TAS 图解</translation>
    </message>
    <message>
        <location filename="__init__.py" line="634"/>
        <source>Trace</source>
        <translation>微量蛛网图</translation>
    </message>
    <message>
        <location filename="__init__.py" line="635"/>
        <source>REE</source>
        <translation>稀土模式图</translation>
    </message>
    <message>
        <location filename="__init__.py" line="636"/>
        <source>Pearce</source>
        <translation>Pearce 图解</translation>
    </message>
    <message>
        <location filename="__init__.py" line="637"/>
        <source>Harker</source>
        <translation>Harker 图解</translation>
    </message>
    <message>
        <location filename="__init__.py" line="638"/>
        <source>CIPW</source>
        <translation>CIPW</translation>
    </message>
    <message>
        <location filename="__init__.py" line="640"/>
        <source>QAPF</source>
        <translation>QAPF 图解</translation>
    </message>
    <message>
        <location filename="__init__.py" line="641"/>
        <source>Saccani Plot</source>
        <translation>Saccani图解</translation>
    </message>
    <message>
        <location filename="__init__.py" line="642"/>
        <source>K2O-SiO2</source>
        <translation></translation>
    </message>
    <message>
        <location filename="__init__.py" line="643"/>
        <source>Raman Strength</source>
        <translation>激光拉曼数据可视化</translation>
    </message>
    <message>
        <location filename="__init__.py" line="644"/>
        <source>Fluid Inclusion</source>
        <translation>流体包裹体</translation>
    </message>
    <message>
        <location filename="__init__.py" line="645"/>
        <source>Harker Classical</source>
        <translation>经典 Harker 图解</translation>
    </message>
    <message>
        <location filename="__init__.py" line="646"/>
        <source>TraceNew</source>
        <translation>新版微量元素</translation>
    </message>
    <message>
        <location filename="__init__.py" line="647"/>
        <source>ZrYSrTi</source>
        <translation></translation>
    </message>
    <message>
        <location filename="__init__.py" line="648"/>
        <source>TiAlCaMgMnKNaSi</source>
        <translation></translation>
    </message>
    <message>
        <location filename="__init__.py" line="650"/>
        <source>Stereo</source>
        <translation>极射赤平投影</translation>
    </message>
    <message>
        <location filename="__init__.py" line="651"/>
        <source>Rose</source>
        <translation>玫瑰花图</translation>
    </message>
    <message>
        <location filename="__init__.py" line="653"/>
        <source>QFL</source>
        <translation>QFL 图解</translation>
    </message>
    <message>
        <location filename="__init__.py" line="654"/>
        <source>QmFLt</source>
        <translation>QmFLt 图解</translation>
    </message>
    <message>
        <location filename="__init__.py" line="655"/>
        <source>Clastic(sand-silt-clay)</source>
        <translation>陆源碎屑</translation>
    </message>
    <message>
        <location filename="__init__.py" line="656"/>
        <source>CIA/ICV/PIA/CIW/CIW&apos;</source>
        <translation></translation>
    </message>
    <message>
        <location filename="__init__.py" line="658"/>
        <source>ZirconCe</source>
        <translation>锆石Ce 氧逸度</translation>
    </message>
    <message>
        <location filename="__init__.py" line="659"/>
        <source>ZirconCeOld</source>
        <translation>锆石Ce 氧逸度旧版</translation>
    </message>
    <message>
        <location filename="__init__.py" line="660"/>
        <source>ZirconTiTemp</source>
        <translation>锆石 Ti 温度计</translation>
    </message>
    <message>
        <location filename="__init__.py" line="661"/>
        <source>RutileZrTemp</source>
        <translation>金红石 Zr 温度计</translation>
    </message>
    <message>
        <location filename="__init__.py" line="662"/>
        <source>Rb-Sr IsoTope</source>
        <translation>Rb-Sr同位素等时线</translation>
    </message>
    <message>
        <location filename="__init__.py" line="663"/>
        <source>Sm-Nd IsoTope</source>
        <translation>Sm-Nd同位素等时线</translation>
    </message>
    <message>
        <location filename="__init__.py" line="666"/>
        <source>X-Y plot</source>
        <translation>自定义平面图解</translation>
    </message>
    <message>
        <location filename="__init__.py" line="667"/>
        <source>X-Y-Z plot</source>
        <translation>自定义三角图解</translation>
    </message>
    <message>
        <location filename="__init__.py" line="668"/>
        <source>Cluster</source>
        <translation>谱系聚类分析</translation>
    </message>
    <message>
        <location filename="__init__.py" line="669"/>
        <source>MultiDimension</source>
        <translation>三维可视化</translation>
    </message>
    <message>
        <location filename="__init__.py" line="671"/>
        <source>Distance</source>
        <translation>距离计算</translation>
    </message>
    <message>
        <location filename="__init__.py" line="673"/>
        <source>Statistics</source>
        <translation>数据统计</translation>
    </message>
    <message>
        <location filename="__init__.py" line="675"/>
        <source>ThreeD</source>
        <translation>三维可视化</translation>
    </message>
    <message>
        <location filename="__init__.py" line="676"/>
        <source>TwoD</source>
        <translation>二维成分数据彩色可视化</translation>
    </message>
    <message>
        <location filename="__init__.py" line="677"/>
        <source>TwoD Grey</source>
        <translation>二维成分数据灰度可视化</translation>
    </message>
    <message>
        <location filename="__init__.py" line="679"/>
        <source>Histogram + KDE Curve</source>
        <translation>直方图+核密度曲线</translation>
    </message>
    <message>
        <location filename="__init__.py" line="680"/>
        <source>Pie Chart</source>
        <translation>饼图</translation>
    </message>
    <message>
        <location filename="__init__.py" line="681"/>
        <source>Bar Chart</source>
        <translation>柱条图</translation>
    </message>
    <message>
        <location filename="__init__.py" line="683"/>
        <source>FA</source>
        <translation>因子分析</translation>
    </message>
    <message>
        <location filename="__init__.py" line="684"/>
        <source>PCA</source>
        <translation>主成分分析</translation>
    </message>
    <message>
        <location filename="__init__.py" line="685"/>
        <source>LDA</source>
        <translation>线性判别分析</translation>
    </message>
    <message>
        <location filename="__init__.py" line="686"/>
        <source>DT</source>
        <translation>深度决策树</translation>
    </message>
    <message>
        <location filename="__init__.py" line="687"/>
        <source>MLP</source>
        <translation type="unfinished">多层感知机</translation>
    </message>
    <message>
        <location filename="__init__.py" line="689"/>
        <source>Check Update</source>
        <translation>检查更新</translation>
    </message>
    <message>
        <location filename="__init__.py" line="690"/>
        <source>English Forum</source>
        <translation>英文论坛</translation>
    </message>
    <message>
        <location filename="__init__.py" line="691"/>
        <source>Github</source>
        <translation>Github</translation>
    </message>
    <message>
        <location filename="__init__.py" line="702"/>
        <source>Load Language</source>
        <translation>加载语言</translation>
    </message>
    <message>
        <location filename="__init__.py" line="735"/>
        <source>NetWork Error</source>
        <translation>网络错误</translation>
    </message>
    <message>
        <location filename="__init__.py" line="744"/>
        <source>Version Online is </source>
        <translation>当前线上最新版本为 </translation>
    </message>
    <message>
        <location filename="__init__.py" line="768"/>
        <source>Version</source>
        <translation>检查更新</translation>
    </message>
    <message>
        <location filename="__init__.py" line="753"/>
        <source>New version available.
 Download and update?</source>
        <translation>发现新版本，是否前往下载？</translation>
    </message>
    <message>
        <location filename="__init__.py" line="768"/>
        <source>This is the latest version.</source>
        <translation>已经是最新版本。</translation>
    </message>
    <message>
        <location filename="__init__.py" line="832"/>
        <source>Choose Language File</source>
        <translation>选择语言文件</translation>
    </message>
    <message>
        <location filename="__init__.py" line="1563"/>
        <source>Warning</source>
        <translation>警告</translation>
    </message>
    <message>
        <location filename="__init__.py" line="845"/>
        <source>Your Data mismatch this Function.
 Some Items missing?
 Or maybe there are blanks in items names?
 Or there are nonnumerical valueï¼</source>
        <translation>你的数据没能用于这一功能,是否缺失项目或者有空白值?</translation>
    </message>
    <message>
        <location filename="__init__.py" line="848"/>
        <source>Your Data mismatch this Function.
 Error infor is:</source>
        <translation>你的数据没能够运行这一功能,错误信息为:</translation>
    </message>
    <message>
        <location filename="__init__.py" line="916"/>
        <source>Ready</source>
        <translation>完毕</translation>
    </message>
    <message>
        <location filename="__init__.py" line="898"/>
        <source>Everything fine and no need to set up.</source>
        <translation>图件信息完整无需设置</translation>
    </message>
    <message>
        <location filename="__init__.py" line="902"/>
        <source>Items added, Modify in the Table to set up details.</source>
        <translation>设置项目已添加，请自行调整颜色分类等信息</translation>
    </message>
    <message>
        <location filename="__init__.py" line="916"/>
        <source>Blanks are now filled with 0s.</source>
        <translation>空白位置已经用零值填充</translation>
    </message>
    <message>
        <location filename="__init__.py" line="1098"/>
        <source>Choose Data File</source>
        <translation>选择数据文件</translation>
    </message>
    <message>
        <location filename="__init__.py" line="1046"/>
        <source>Save Data File</source>
        <translation>存储数据文件</translation>
    </message>
    <message>
        <location filename="__init__.py" line="1210"/>
        <source>Done</source>
        <translation>完工！</translation>
    </message>
    <message>
        <location filename="__init__.py" line="1210"/>
        <source>LOI has been removed!:</source>
        <translation>烧式量已经移除</translation>
    </message>
    <message>
        <location filename="__init__.py" line="1563"/>
        <source>Your data contain no Q/A/P/F data.
 Maybe you need to run CIPW first?</source>
        <translation>你的数据压根就没有包含 QAPF 信息，先 CIPW 算出来 QAPF 的值再说吧！</translation>
    </message>
</context>
</TS>

==> geopytool-0.9.21.0.4.tar.gz: geopytool-0.9.21.0.4/geopytool/cns.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="zh" sourcelanguage="en">
<context>
    <name>MainWindow</name>
    <message>
        <location filename="__init__.py" line="140"/>
        <source>GeoPyTool</source>
        <translation>GeoPyTool</translation>
    </message>
    <message>
        <location filename="__init__.py" line="744"/>
        <source>You are using GeoPyTool </source>
        <translation>你正在使用的是 GeoPyTool</translation>
    </message>
    <message>
        <location filename="__init__.py" line="745"/>
        <source>released on </source>
        <translation>发布日期为 </translation>
    </message>
    <message>
        <location filename="__init__.py" line="605"/>
        <source>Data File</source>
        <translation>数据文件</translation>
    </message>
    <message>
        <location filename="__init__.py" line="606"/>
        <source>Geochemistry</source>
        <translation>地球化学</translation>
    </message>
    <message>
        <location filename="__init__.py" line="607"/>
        <source>Calculation</source>
        <translation>多维度分析</translation>
    </message>
    <message>
        <location filename="__init__.py" line="608"/>
        <source>Structure</source>
        <translation>构造地质学</translation>
    </message>
    <message>
        <location filename="__init__.py" line="609"/>
        <source>Sedimentary</source>
        <translation>沉积相关</translation>
    </message>
    <message>
        <location filename="__init__.py" line="610"/>
        <source>Additional</source>
        <translation>附加功能</translation>
    </message>
    <message>
        <location filename="__init__.py" line="611"/>
        <source>MachineLearn</source>
        <translation>机器学习</translation>
    </message>
    <message>
        <location filename="__init__.py" line="612"/>
        <source>Help</source>
        <translation>帮助</translation>
    </message>
    <message>
        <location filename="__init__.py" line="613"/>
        <source>Language</source>
        <translation></translation>
    </message>
    <message>
        <location filename="__init__.py" line="615"/>
        <source>Combine</source>
        <translation>合并数据表</translation>
    </message>
    <message>
        <location filename="__init__.py" line="616"/>
        <source>Combine_transverse</source>
        <translation>合并转置</translation>
    </message>
    <message>
        <location filename="__init__.py" line="618"/>
        <source>Flatten</source>
        <translation>二维数据拉平成一维</translation>
    </message>
    <message>
        <location filename="__init__.py" line="620"/>
        <source>Trans</source>
        <translation>数据变换</translation>
    </message>
    <message>
        <location filename="__init__.py" line="622"/>
        <source>ReFormat</source>
        <translation>重新格式化</translation>
    </message>
    <message>
        <location filename="__init__.py" line="624"/>
        <source>Open Data</source>
        <translation>导入数据</translation>
    </message>
    <message>
        <location filename="__init__.py" line="625"/>
        <source>Close Data</source>
        <translation>关闭文件</translation>
    </message>
    <message>
        <location filename="__init__.py" line="626"/>
        <source>Set Format</source>
        <translation>设置数据</translation>
    </message>
    <message>
        <location filename="__init__.py" line="627"/>
        <source>Fill Blank with 0</source>
        <translation>用零值填充空白</translation>
    </message>
    <message>
        <location filename="__init__.py" line="628"/>
        <source>Save Data</source>
        <translation>保存数据</translation>
    </message>
    <message>
        <location filename="__init__.py" line="629"/>
        <source>Quit App</source>
        <translation>退出程序</translation>
    </message>
    <message>
        <location filename="__init__.py" line="631"/>
        <source>Remove LOI</source>
        <translation>去除烧失量</translation>
    </message>
    <message>
        <location filename="__init__.py" line="632"/>
        <source>Auto</source>
        <translation>常规地化图解计算自动生成</translation>
    </message>
    <message>
        <location filename="__init__.py" line="633"/>
        <source>TAS</source>
        <translation>TAS 图解</translation>
    </message>
    <message>
        <location filename="__init__.py" line="634"/>
        <source>Trace</source>
        <translation>微量蛛网图</translation>
    </message>
    <message>
        <location filename="__init__.py" line="635"/>
        <source>REE</source>
        <translation>稀土模式图</translation>
    </message>
    <message>
        <location filename="__init__.py" line="636"/>
        <source>Pearce</source>
        <translation>Pearce 图解</translation>
    </message>
    <message>
        <location filename="__init__.py" line="637"/>
        <source>Harker</source>
        <translation>Harker 图解</translation>
    </message>
    <message>
        <location filename="__init__.py" line="638"/>
        <source>CIPW</source>
        <translation>CIPW</translation>
    </message>
    <message>
        <location filename="__init__.py" line="640"/>
        <source>QAPF</source>
        <translation>QAPF 图解</translation>
    </message>
    <message>
        <location filename="__init__.py" line="641"/>
        <source>Saccani Plot</source>
        <translation>Saccani图解</translation>
    </message>
    <message>
        <location filename="__init__.py" line="642"/>
        <source>K2O-SiO2</source>
        <translation></translation>
    </message>
    <message>
        <location filename="__init__.py" line="643"/>
        <source>Raman Strength</source>
        <translation>激光拉曼数据可视化</translation>
    </message>
    <message>
        <location filename="__init__.py" line="644"/>
        <source>Fluid Inclusion</source>
        <translation>流体包裹体</translation>
    </message>
    <message>
        <location filename="__init__.py" line="645"/>
        <source>Harker Classical</source>
        <translation>经典 Harker 图解</translation>
    </message>
    <message>
        <location filename="__init__.py" line="646"/>
        <source>TraceNew</source>
        <translation>新版微量元素</translation>
    </message>
    <message>
        <location filename="__init__.py" line="647"/>
        <source>ZrYSrTi</source>
        <translation></translation>
    </message>
    <message>
        <location filename="__init__.py" line="648"/>
        <source>TiAlCaMgMnKNaSi</source>
        <translation></translation>
    </message>
    <message>
        <location filename="__init__.py" line="650"/>
        <source>Stereo</source>
        <translation>极射赤平投影</translation>
    </message>
    <message>
        <location filename="__init__.py" line="651"/>
        <source>Rose</source>
        <translation>玫瑰花图</translation>
    </message>
    <message>
        <location filename="__init__.py" line="653"/>
        <source>QFL</source>
        <translation>QFL 图解</translation>
    </message>
    <message>
        <location filename="__init__.py" line="654"/>
        <source>QmFLt</source>
        <translation>QmFLt 图解</translation>
    </message>
    <message>
        <location filename="__init__.py" line="655"/>
        <source>Clastic(sand-silt-clay)</source>
        <translation>陆源碎屑</translation>
    </message>
    <message>
        <location filename="__init__.py" line="656"/>
        <source>CIA/ICV/PIA/CIW/CIW&apos;</source>
        <translation></translation>
    </message>
    <message>
        <location filename="__init__.py" line="658"/>
        <source>ZirconCe</source>
        <translation>锆石Ce 氧逸度</translation>
    </message>
    <message>
        <location filename="__init__.py" line="659"/>
        <source>ZirconCeOld</source>
        <translation>锆石Ce 氧逸度旧版</translation>
    </message>
    <message>
        <location filename="__init__.py" line="660"/>
        <source>ZirconTiTemp</source>
        <translation>锆石 Ti 温度计</translation>
    </message>
    <message>
        <location filename="__init__.py" line="661"/>
        <source>RutileZrTemp</source>
        <translation>金红石 Zr 温度计</translation>
    </message>
    <message>
        <location filename="__init__.py" line="662"/>
        <source>Rb-Sr IsoTope</source>
        <translation>Rb-Sr同位素等时线</translation>
    </message>
    <message>
        <location filename="__init__.py" line="663"/>
        <source>Sm-Nd IsoTope</source>
        <translation>Sm-Nd同位素等时线</translation>
    </message>
    <message>
        <location filename="__init__.py" line="666"/>
        <source>X-Y plot</source>
        <translation>自定义平面图解</translation>
    </message>
    <message>
        <location filename="__init__.py" line="667"/>
        <source>X-Y-Z plot</source>
        <translation>自定义三角图解</translation>
    </message>
    <message>
        <location filename="__init__.py" line="668"/>
        <source>Cluster</source>
        <translation>谱系聚类分析</translation>
    </message>
    <message>
        <location filename="__init__.py" line="669"/>
        <source>MultiDimension</source>
        <translation>三维可视化</translation>
    </message>
    <message>
        <location filename="__init__.py" line="671"/>
        <source>Distance</source>
        <translation>距离计算</translation>
    </message>
    <message>
        <location filename="__init__.py" line="673"/>
        <source>Statistics</source>
        <translation>数据统计</translation>
    </message>
    <message>
        <location filename="__init__.py" line="675"/>
        <source>ThreeD</source>
        <translation>三维可视化</translation>
    </message>
    <message>
        <location filename="__init__.py" line="676"/>
        <source>TwoD</source>
        <translation>二维成分数据彩色可视化</translation>
    </message>
    <message>
        <location filename="__init__.py" line="677"/>
        <source>TwoD Grey</source>
        <translation>二维成分数据灰度可视化</translation>
    </message>
    <message>
        <location filename="__init__.py" line="679"/>
        <source>Histogram + KDE Curve</source>
        <translation>直方图+核密度曲线</translation>
    </message>
    <message>
        <location filename="__init__.py" line="680"/>
        <source>Pie Chart</source>
        <translation>饼图</translation>
    </message>
    <message>
        <location filename="__init__.py" line="681"/>
        <source>Bar Chart</source>
        <translation>柱条图</translation>
    </message>
    <message>
        <location filename="__init__.py" line="683"/>
        <source>FA</source>
        <translation>因子分析</translation>
    </message>
    <message>
        <location filename="__init__.py" line="684"/>
        <source>PCA</source>
        <translation>主成分分析</translation>
    </message>
    <message>
        <location filename="__init__.py" line="685"/>
        <source>LDA</source>
        <translation>线性判别分析</translation>
    </message>
    <message>
        <location filename="__init__.py" line="686"/>
        <source>DT</source>
        <translation>深度决策树</translation>
    </message>
    <message>
        <location filename="__init__.py" line="687"/>
        <source>MLP</source>
        <translation>多层感知机</translation>
    </message>
    <message>
        <location filename="__init__.py" line="689"/>
        <source>Check Update</source>
        <translation>检查更新</translation>
    </message>
    <message>
        <location filename="__init__.py" line="690"/>
        <source>English Forum</source>
        <translation>英文论坛</translation>
    </message>
    <message>
        <location filename="__init__.py" line="691"/>
        <source>Github</source>
        <translation>Github</translation>
    </message>
    <message>
        <location filename="__init__.py" line="702"/>
        <source>Load Language</source>
        <translation>加载语言</translation>
    </message>
    <message>
        <location filename="__init__.py" line="735"/>
        <source>NetWork Error</source>
        <translation>网络错误</translation>
    </message>
    <message>
        <location filename="__init__.py" line="744"/>
        <source>Version Online is </source>
        <translation>当前线上最新版本为 </translation>
    </message>
    <message>
        <location filename="__init__.py" line="768"/>
        <source>Version</source>
        <translation>检查更新</translation>
    </message>
    <message>
        <location filename="__init__.py" line="753"/>
        <source>New version available.
 Download and update?</source>
        <translation>发现新版本，是否前往下载？</translation>
    </message>
    <message>
        <location filename="__init__.py" line="768"/>
        <source>This is the latest version.</source>
        <translation>已经是最新版本。</translation>
    </message>
    <message>
        <location filename="__init__.py" line="832"/>
        <source>Choose Language File</source>
        <translation>选择语言文件</translation>
    </message>
    <message>
        <location filename="__init__.py" line="1563"/>
        <source>Warning</source>
        <translation>警告</translation>
    </message>
    <message>
        <location filename="__init__.py" line="845"/>
        <source>Your Data mismatch this Function.
 Some Items missing?
 Or maybe there are blanks in items names?
 Or there are nonnumerical valueï¼</source>
        <translation>你的数据没能用于这一功能,是否缺失项目或者有空白值?</translation>
    </message>
    <message>
        <location filename="__init__.py" line="848"/>
        <source>Your Data mismatch this Function.
 Error infor is:</source>
        <translation>你的数据没能够运行这一功能,错误信息为:</translation>
    </message>
    <message>
        <location filename="__init__.py" line="916"/>
        <source>Ready</source>
        <translation>完毕</translation>
    </message>
    <message>
        <location filename="__init__.py" line="898"/>
        <source>Everything fine and no need to set up.</source>
        <translation>图件信息完整无需设置</translation>
    </message>
    <message>
        <location filename="__init__.py" line="902"/>
        <source>Items added, Modify in the Table to set up details.</source>
        <translation>设置项目已添加，请自行调整颜色分类等信息</translation>
    </message>
    <message>
        <location filename="__init__.py" line="916"/>
        <source>Blanks are now filled with 0s.</source>
        <translation>空白位置已经用零值填充</translation>
    </message>
    <message>
        <location filename="__init__.py" line="1098"/>
        <source>Choose Data File</source>
        <translation>选择数据文件</translation>
    </message>
    <message>
        <location filename="__init__.py" line="1046"/>
        <source>Save Data File</source>
        <translation>存储数据文件</translation>
    </message>
    <message>
        <location filename="__init__.py" line="1210"/>
        <source>Done</source>
        <translation>完工！</translation>
    </message>
    <message>
        <location filename="__init__.py" line="1210"/>
        <source>LOI has been removed!:</source>
        <translation>烧失量已经移除</translation>
    </message>
    <message>
        <location filename="__init__.py" line="1563"/>
        <source>Your data contain no Q/A/P/F data.
 Maybe you need to run CIPW first?</source>
        <translation>你的数据压根就没有包含 QAPF 信息，先 CIPW 算出来 QAPF 的值再说吧！</translation>
    </message>
</context>
</TS>
